@@ -1,5 +1,8 @@
 package Linux::Perl;
 
+use strict;
+use warnings;
+
 =encoding utf-8
 
 =head1 NAME
@@ -15,6 +18,10 @@ Linux::Perl - Linux system calls with pure Perl
 
 =head1 DESCRIPTION
 
+Linux::Perl’s goal is to provide, without use of XS, feature-complete
+implementations of Linux kernel features that the Perl interpreter does
+not expose.
+
 In memory-sensitive environments it is useful to minimize the number
 of XS modules that Perl loads. Oftentimes the CPAN modules that implement
 support for various Linux system calls, though, will bring in XS for the
@@ -53,6 +60,10 @@ Each family of system calls lives in its own namespace under C<Linux::Perl>:
 
 =item * L<Linux::Perl::mq>
 
+=item * L<Linux::Perl::sendmsg>
+
+=item * L<Linux::Perl::prlimit>
+
 =back
 
 The distribution contains a number of other modules, none of which is
@@ -60,9 +71,13 @@ currently intended for outside use.
 
 =head1 PLATFORM-SPECIFIC INVOCATION
 
-Each Linux::Perl system call implementation can be called with a
-platform-neutral syntax as well as with a platform-specific one;
-for example:
+Linux::Perl achieves functionality by hard-coding each supported platform’s
+number for each required system call. As a consequence, any new platforms’
+system calls will need to be added manually.
+
+To allow optimization for portability or efficiency, each implementation
+can be called with a platform-neutral syntax as well as with a
+platform-specific one; for example:
 
     my $efd = Linux::Perl::eventfd->new();
 
@@ -73,8 +88,8 @@ L<Config> to determine the current platform.
 
 =head1 PLATFORM SUPPORT
 
-C<x86_64> and C<arm> are the best-supported platforms. Limited support
-is included for C<i686> and C<i386>.
+C<x86_64> and C<arm> are the best-supported platforms. C<i686> and C<i386>
+also have some support.
 
 Support for adding new platforms just involves adding new modules with the
 necessary constants to the distribution.
@@ -83,12 +98,9 @@ Note also that a 64-bit Perl is generally assumed.
 
 =cut
 
-use strict;
-use warnings;
-
 use Linux::Perl::X ();
 
-our $VERSION = '0.13-TRIAL5';
+our $VERSION = '0.16-TRIAL5';
 
 our @_TOLERATE_ERRNO;
 
